Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sbin/newfs Adjust column-sizing code to keep output in 76 ch...



details:   https://anonhg.NetBSD.org/src/rev/e4a42dce0c1e
branches:  trunk
changeset: 475059:e4a42dce0c1e
user:      wrstuden <wrstuden%NetBSD.org@localhost>
date:      Fri Jul 30 17:44:01 1999 +0000

description:
Adjust column-sizing code to keep output in 76 character lines, so output
doesn't wrap in sysinst.

diffstat:

 sbin/newfs/mkfs.c |  9 +++++----
 1 files changed, 5 insertions(+), 4 deletions(-)

diffs (33 lines):

diff -r b997f579fdf9 -r e4a42dce0c1e sbin/newfs/mkfs.c
--- a/sbin/newfs/mkfs.c Fri Jul 30 16:23:43 1999 +0000
+++ b/sbin/newfs/mkfs.c Fri Jul 30 17:44:01 1999 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: mkfs.c,v 1.36 1999/05/14 22:36:50 wrstuden Exp $       */
+/*     $NetBSD: mkfs.c,v 1.37 1999/07/30 17:44:01 wrstuden Exp $       */
 
 /*
  * Copyright (c) 1980, 1989, 1993
@@ -38,7 +38,7 @@
 #if 0
 static char sccsid[] = "@(#)mkfs.c     8.11 (Berkeley) 5/3/95";
 #else
-__RCSID("$NetBSD: mkfs.c,v 1.36 1999/05/14 22:36:50 wrstuden Exp $");
+__RCSID("$NetBSD: mkfs.c,v 1.37 1999/07/30 17:44:01 wrstuden Exp $");
 #endif
 #endif /* not lint */
 
@@ -601,11 +601,12 @@
        }
        /*
         * Now determine how wide each column will be, and calculate how
         * many columns will fit in an 80 char line.
         */
        printcolwidth = count_digits(
                        fsbtodb(&sblock, cgsblock(&sblock, sblock.fs_ncg -1)));
-       nprintcols = 80 / (printcolwidth + 2);
+       nprintcols = 76 / (printcolwidth + 2);
        /*
         * Now build the cylinders group blocks and
         * then print out indices of cylinder groups.
@@ -601,11 +601,12 @@
        /*
         * Now determine how wide each column will be, and calculate how
-        * many columns will fit in an 80 char line.
+        * many columns will fit in a 76 char line. 76 is the width of the
+        * subwindows in sysinst.
         */
        printcolwidth = count_digits(



Home | Main Index | Thread Index | Old Index